@@ -1,6 +1,7 @@
 #-*- coding: utf-8 -*-
 
 from django import forms
+from django.utils import timezone
 
 import djconfig
 from djconfig.models import Config
@@ -20,7 +21,10 @@ class ConfigForm(forms.Form):
                         for field_name in self.fields}
 
     def save(self):
-        for field_name, value in self.cleaned_data.iteritems():
+        data = self.cleaned_data
+        data['_updated_at'] = timezone.now()
+
+        for field_name, value in data.iteritems():
             count = Config.objects.filter(key=field_name).update(value=value)
 
             if not count:
